diff core/NetworkSend.cpp @ 301:e4392164b458 prerelease

RENAMED BeagleRT to Bela AAAAAAAAAAAAAAAAAAAAAAAAAAAAAA, scripts probably not working
author Giulio Moro <giuliomoro@yahoo.it>
date Fri, 27 May 2016 14:34:41 +0100
parents 6a23c07d0fbb
children
line wrap: on
line diff
--- a/core/NetworkSend.cpp	Fri May 27 13:58:20 2016 +0100
+++ b/core/NetworkSend.cpp	Fri May 27 14:34:41 2016 +0100
@@ -19,7 +19,7 @@
 	staticConstructed=true;
 	threadIsExiting=false;
 	threadRunning=false;
-	sendDataTask = BeagleRT_createAuxiliaryTask(::sendData, 95, "sendDataTask"); //TODO: allow variable priority
+	sendDataTask = Bela_createAuxiliaryTask(::sendData, 95, "sendDataTask"); //TODO: allow variable priority
 }
 void NetworkSend::sendAllData(){
 	for(unsigned int n=0; n<NetworkSend::objAddrs.size(); n++){
@@ -30,7 +30,7 @@
 	return objAddrs.size();
 }
 void NetworkSend::startThread(){
-	BeagleRT_scheduleAuxiliaryTask(sendDataTask);
+	Bela_scheduleAuxiliaryTask(sendDataTask);
 }
 void NetworkSend::stopThread(){
 	threadIsExiting=true;
@@ -95,7 +95,7 @@
 #ifdef USE_JUCE
 #else
 	staticConstructor(); //FIXME: ideally this should be in the constructor, but this is not currently possible
 						//because of limitations in BeagleRT_createAuxiliaryTask()
 	//keep track of added active instances
 	objAddrs.push_back(this);//TODO: this line should be in the constructor, but something weird happens if
 	// an instance of NetworkSend is then declared globally: the constructor gets called,
@@ -95,7 +95,7 @@
 #else
 	staticConstructor(); //FIXME: ideally this should be in the constructor, but this is not currently possible
-						//because of limitations in BeagleRT_createAuxiliaryTask()
+						//because of limitations in Bela_createAuxiliaryTask()
 	//keep track of added active instances
 	objAddrs.push_back(this);//TODO: this line should be in the constructor, but something weird happens if